package com.huashe.park.core.service;


import com.huashe.park.domain.entity.BdFenceVioEvt;

import java.util.List;

/**
 * 围栏闯禁事件Service接口
 *
 * @author ruoyi
 * @date 2024-10-14
 */
public interface IBdFenceVioEvtService
{
    /**
     * 查询围栏闯禁事件
     *
     * @param id 围栏闯禁事件主键
     * @return 围栏闯禁事件
     */
    public BdFenceVioEvt selectBdFenceVioEvtById(Long id);

    /**
     * 查询围栏闯禁事件列表
     *
     * @param bdFenceVioEvt 围栏闯禁事件
     * @return 围栏闯禁事件集合
     */
    public List<BdFenceVioEvt> selectBdFenceVioEvtList(BdFenceVioEvt bdFenceVioEvt);

    /**
     * 新增围栏闯禁事件
     *
     * @param bdFenceVioEvt 围栏闯禁事件
     * @return 结果
     */
    public int insertBdFenceVioEvt(BdFenceVioEvt bdFenceVioEvt);

    /**
     * 修改围栏闯禁事件
     *
     * @param bdFenceVioEvt 围栏闯禁事件
     * @return 结果
     */
    public int updateBdFenceVioEvt(BdFenceVioEvt bdFenceVioEvt);

    /**
     * 批量删除围栏闯禁事件
     *
     * @param ids 需要删除的围栏闯禁事件主键集合
     * @return 结果
     */
    public int deleteBdFenceVioEvtByIds(Long[] ids);

    /**
     * 删除围栏闯禁事件信息
     *
     * @param id 围栏闯禁事件主键
     * @return 结果
     */
    public int deleteBdFenceVioEvtById(Long id);
}
